@@ -397,6 +397,10 @@ class GoogleAPIResource(Resource):
 
         return labels
 
+    @property
+    def resource_name(self):
+        return self._resource_data.get('name')
+
     @property
     def project_id(self):
         return self._resource_data.get('project_id')
@@ -561,6 +565,23 @@ class GcpComputeRegionDisk(GoogleAPIResource):
         }
 
 
+class GcpComputeNetwork(GoogleAPIResource):
+
+    service_name = "compute"
+    resource_path = "networks"
+    version = "v1"
+
+    required_resource_data = ['name', 'project_id']
+
+    resource_type = "compute.googleapis.com/Network"
+
+    def _get_request_args(self):
+        return {
+            'project': self._resource_data['project_id'],
+            'network': self._resource_data['name']
+        }
+
+
 class GcpComputeSubnetwork(GoogleAPIResource):
 
     service_name = "compute"
@@ -736,6 +757,7 @@ class GcpIamServiceAccountKey(GoogleAPIResource):
             )
         }
 
+
 class GcpPubsubSubscription(GoogleAPIResource):
 
     service_name = "pubsub"
@@ -922,6 +944,7 @@ class GcpDataflowJob(GoogleAPIResource):
             'view': 'JOB_VIEW_DESCRIPTION'
         }
 
+
 class GcpRedisInstance(GoogleAPIResource):
 
     service_name = "redis"
@@ -945,6 +968,7 @@ class GcpRedisInstance(GoogleAPIResource):
             ),
         }
 
+
 class GcpMemcacheInstance(GoogleAPIResource):
 
     service_name = "memcache"
